pre { line-height: 125%; }
td.linenos pre { color: #000000; background-color: #f0f0f0; padding-left: 5px; padding-right: 5px; }
span.linenos { color: #000000; background-color: #f0f0f0; padding-left: 5px; padding-right: 5px; }
td.linenos pre.special { color: #000000; background-color: #ffffc0; padding-left: 5px; padding-right: 5px; }
span.linenos.special { color: #000000; background-color: #ffffc0; padding-left: 5px; padding-right: 5px; }
.codehilite .hll { background-color: #ffffcc }
.codehilite { background: #f8f8f8; }
.codehilite .c { color: #408080; font-style: italic } /* Comment */
.codehilite .err { border: 1px solid #FF0000 } /* Error */
.codehilite .k { color: #008000; font-weight: bold } /* Keyword */
.codehilite .o { color: #666666 } /* Operator */
.codehilite .ch { color: #408080; font-style: italic } /* Comment.Hashbang */
.codehilite .cm { color: #408080; font-style: italic } /* Comment.Multiline */
.codehilite .cp { color: #BC7A00 } /* Comment.Preproc */
.codehilite .cpf { color: #408080; font-style: italic } /* Comment.PreprocFile */
.codehilite .c1 { color: #408080; font-style: italic } /* Comment.Single */
.codehilite .cs { color: #408080; font-style: italic } /* Comment.Special */
.codehilite .gd { color: #A00000 } /* Generic.Deleted */
.codehilite .ge { font-style: italic } /* Generic.Emph */
.codehilite .gr { color: #FF0000 } /* Generic.Error */
.codehilite .gh { color: #000080; font-weight: bold } /* Generic.Heading */
.codehilite .gi { color: #00A000 } /* Generic.Inserted */
.codehilite .go { color: #888888 } /* Generic.Output */
.codehilite .gp { color: #000080; font-weight: bold } /* Generic.Prompt */
.codehilite .gs { font-weight: bold } /* Generic.Strong */
.codehilite .gu { color: #800080; font-weight: bold } /* Generic.Subheading */
.codehilite .gt { color: #0044DD } /* Generic.Traceback */
.codehilite .kc { color: #008000; font-weight: bold } /* Keyword.Constant */
.codehilite .kd { color: #008000; font-weight: bold } /* Keyword.Declaration */
.codehilite .kn { color: #008000; font-weight: bold } /* Keyword.Namespace */
.codehilite .kp { color: #008000 } /* Keyword.Pseudo */
.codehilite .kr { color: #008000; font-weight: bold } /* Keyword.Reserved */
.codehilite .kt { color: #B00040 } /* Keyword.Type */
.codehilite .m { color: #666666 } /* Literal.Number */
.codehilite .s { color: #BA2121 } /* Literal.String */
.codehilite .na { color: #7D9029 } /* Name.Attribute */
.codehilite .nb { color: #008000 } /* Name.Builtin */
.codehilite .nc { color: #0000FF; font-weight: bold } /* Name.Class */
.codehilite .no { color: #880000 } /* Name.Constant */
.codehilite .nd { color: #AA22FF } /* Name.Decorator */
.codehilite .ni { color: #999999; font-weight: bold } /* Name.Entity */
.codehilite .ne { color: #D2413A; font-weight: bold } /* Name.Exception */
.codehilite .nf { color: #0000FF } /* Name.Function */
.codehilite .nl { color: #A0A000 } /* Name.Label */
.codehilite .nn { color: #0000FF; font-weight: bold } /* Name.Namespace */
.codehilite .nt { color: #008000; font-weight: bold } /* Name.Tag */
.codehilite .nv { color: #19177C } /* Name.Variable */
.codehilite .ow { color: #AA22FF; font-weight: bold } /* Operator.Word */
.codehilite .w { color: #bbbbbb } /* Text.Whitespace */
.codehilite .mb { color: #666666 } /* Literal.Number.Bin */
.codehilite .mf { color: #666666 } /* Literal.Number.Float */
.codehilite .mh { color: #666666 } /* Literal.Number.Hex */
.codehilite .mi { color: #666666 } /* Literal.Number.Integer */
.codehilite .mo { color: #666666 } /* Literal.Number.Oct */
.codehilite .sa { color: #BA2121 } /* Literal.String.Affix */
.codehilite .sb { color: #BA2121 } /* Literal.String.Backtick */
.codehilite .sc { color: #BA2121 } /* Literal.String.Char */
.codehilite .dl { color: #BA2121 } /* Literal.String.Delimiter */
.codehilite .sd { color: #BA2121; font-style: italic } /* Literal.String.Doc */
.codehilite .s2 { color: #BA2121 } /* Literal.String.Double */
.codehilite .se { color: #BB6622; font-weight: bold } /* Literal.String.Escape */
.codehilite .sh { color: #BA2121 } /* Literal.String.Heredoc */
.codehilite .si { color: #BB6688; font-weight: bold } /* Literal.String.Interpol */
.codehilite .sx { color: #008000 } /* Literal.String.Other */
.codehilite .sr { color: #BB6688 } /* Literal.String.Regex */
.codehilite .s1 { color: #BA2121 } /* Literal.String.Single */
.codehilite .ss { color: #19177C } /* Literal.String.Symbol */
.codehilite .bp { color: #008000 } /* Name.Builtin.Pseudo */
.codehilite .fm { color: #0000FF } /* Name.Function.Magic */
.codehilite .vc { color: #19177C } /* Name.Variable.Class */
.codehilite .vg { color: #19177C } /* Name.Variable.Global */
.codehilite .vi { color: #19177C } /* Name.Variable.Instance */
.codehilite .vm { color: #19177C } /* Name.Variable.Magic */
.codehilite .il { color: #666666 } /* Literal.Number.Integer.Long */

/* Dark theme */
@media (prefers-color-scheme: dark) {
  .codehilite {
    background-color: #333;
    color: #ccc;
  }

  pre { line-height: 125%; }
  td.linenos pre { color: #cccccc; background-color: #2a2a2a; padding-left: 5px; padding-right: 5px; }
  span.linenos { color: #cccccc; background-color: #2a2a2a; padding-left: 5px; padding-right: 5px; }
  td.linenos pre.special { color: #cccccc; background-color: #4a4a00; padding-left: 5px; padding-right: 5px; }
  span.linenos.special { color: #cccccc; background-color: #4a4a00; padding-left: 5px; padding-right: 5px; }
  .codehilite .hll { background-color: #404040 }
  .codehilite { background: #1e1e1e; }
  .codehilite .c { color: #75b5aa; font-style: italic } /* Comment */
  .codehilite .err { border: 1px solid #ff6b6b } /* Error */
  .codehilite .k { color: #569cd6; font-weight: bold } /* Keyword */
  .codehilite .o { color: #d4d4d4 } /* Operator */
  .codehilite .ch { color: #75b5aa; font-style: italic } /* Comment.Hashbang */
  .codehilite .cm { color: #75b5aa; font-style: italic } /* Comment.Multiline */
  .codehilite .cp { color: #ffd700 } /* Comment.Preproc */
  .codehilite .cpf { color: #75b5aa; font-style: italic } /* Comment.PreprocFile */
  .codehilite .c1 { color: #75b5aa; font-style: italic } /* Comment.Single */
  .codehilite .cs { color: #75b5aa; font-style: italic } /* Comment.Special */
  .codehilite .gd { color: #f85552 } /* Generic.Deleted */
  .codehilite .ge { font-style: italic } /* Generic.Emph */
  .codehilite .gr { color: #ff6b6b } /* Generic.Error */
  .codehilite .gh { color: #9cdcfe; font-weight: bold } /* Generic.Heading */
  .codehilite .gi { color: #73c991 } /* Generic.Inserted */
  .codehilite .go { color: #808080 } /* Generic.Output */
  .codehilite .gp { color: #9cdcfe; font-weight: bold } /* Generic.Prompt */
  .codehilite .gs { font-weight: bold } /* Generic.Strong */
  .codehilite .gu { color: #c586c0; font-weight: bold } /* Generic.Subheading */
  .codehilite .gt { color: #4fc1ff } /* Generic.Traceback */
  .codehilite .kc { color: #569cd6; font-weight: bold } /* Keyword.Constant */
  .codehilite .kd { color: #569cd6; font-weight: bold } /* Keyword.Declaration */
  .codehilite .kn { color: #569cd6; font-weight: bold } /* Keyword.Namespace */
  .codehilite .kp { color: #569cd6 } /* Keyword.Pseudo */
  .codehilite .kr { color: #569cd6; font-weight: bold } /* Keyword.Reserved */
  .codehilite .kt { color: #4ec9b0 } /* Keyword.Type */
  .codehilite .m { color: #b5cea8 } /* Literal.Number */
  .codehilite .s { color: #ce9178 } /* Literal.String */
  .codehilite .na { color: #92c5f8 } /* Name.Attribute */
  .codehilite .nb { color: #dcdcaa } /* Name.Builtin */
  .codehilite .nc { color: #4ec9b0; font-weight: bold } /* Name.Class */
  .codehilite .no { color: #4fc1ff } /* Name.Constant */
  .codehilite .nd { color: #c586c0 } /* Name.Decorator */
  .codehilite .ni { color: #b4b4b4; font-weight: bold } /* Name.Entity */
  .codehilite .ne { color: #f85552; font-weight: bold } /* Name.Exception */
  .codehilite .nf { color: #dcdcaa } /* Name.Function */
  .codehilite .nl { color: #d7ba7d } /* Name.Label */
  .codehilite .nn { color: #4ec9b0; font-weight: bold } /* Name.Namespace */
  .codehilite .nt { color: #569cd6; font-weight: bold } /* Name.Tag */
  .codehilite .nv { color: #9cdcfe } /* Name.Variable */
  .codehilite .ow { color: #c586c0; font-weight: bold } /* Operator.Word */
  .codehilite .w { color: #6a6a6a } /* Text.Whitespace */
  .codehilite .mb { color: #b5cea8 } /* Literal.Number.Bin */
  .codehilite .mf { color: #b5cea8 } /* Literal.Number.Float */
  .codehilite .mh { color: #b5cea8 } /* Literal.Number.Hex */
  .codehilite .mi { color: #b5cea8 } /* Literal.Number.Integer */
  .codehilite .mo { color: #b5cea8 } /* Literal.Number.Oct */
  .codehilite .sa { color: #ce9178 } /* Literal.String.Affix */
  .codehilite .sb { color: #ce9178 } /* Literal.String.Backtick */
  .codehilite .sc { color: #ce9178 } /* Literal.String.Char */
  .codehilite .dl { color: #ce9178 } /* Literal.String.Delimiter */
  .codehilite .sd { color: #ce9178; font-style: italic } /* Literal.String.Doc */
  .codehilite .s2 { color: #ce9178 } /* Literal.String.Double */
  .codehilite .se { color: #d7ba7d; font-weight: bold } /* Literal.String.Escape */
  .codehilite .sh { color: #ce9178 } /* Literal.String.Heredoc */
  .codehilite .si { color: #d7ba7d; font-weight: bold } /* Literal.String.Interpol */
  .codehilite .sx { color: #ce9178 } /* Literal.String.Other */
  .codehilite .sr { color: #d16969 } /* Literal.String.Regex */
  .codehilite .s1 { color: #ce9178 } /* Literal.String.Single */
  .codehilite .ss { color: #9cdcfe } /* Literal.String.Symbol */
  .codehilite .bp { color: #dcdcaa } /* Name.Builtin.Pseudo */
  .codehilite .fm { color: #dcdcaa } /* Name.Function.Magic */
  .codehilite .vc { color: #9cdcfe } /* Name.Variable.Class */
  .codehilite .vg { color: #9cdcfe } /* Name.Variable.Global */
  .codehilite .vi { color: #9cdcfe } /* Name.Variable.Instance */
  .codehilite .vm { color: #9cdcfe } /* Name.Variable.Magic */
  .codehilite .il { color: #b5cea8 } /* Literal.Number.Integer.Long */
}
